import{Z as n}from"./index-D6xcdmSy.js";const e=n("language",{state:()=>({langData:"en-US",langOptionsData:[{value:"en-US",label:"English"},{value:"zh-CN",label:"中文简体"}]}),getters:{langGet(a){return a.langData},langOptionGet(a){return a.langOptionsData}},actions:{LangChange:function(a){this.langData=a},langOptionsChange(a){this.lanOptionsData=a}},persist:{enable:!0}});export{e as u};
