import{Q as s}from"./QPage-DjgmKzZ_.js";import{u as n}from"./use-meta-Drr87NGw.js";import{u as m,_ as c}from"./MDParser-CdzFjUMI.js";import{r as o,o as i,e as p,ab as u,a3 as f,a7 as d,a6 as l}from"./index-D6xcdmSy.js";import"./rightDrawer-CSGq-HBq.js";import"./axios-B_9szzRp.js";import"./_commonjsHelpers-Cpj98o6Y.js";import"./use-quasar-CxlsMA-r.js";import"./language-BmNUDO97.js";import"./vue-i18n.runtime-BS3IaizX.js";const N={__name:"BomiotconfReader",setup(_){const t=o(""),e=o(""),a=o(""),r=m();return n(()=>({title:t.value,meta:{description:{name:"description",content:e.value},keywords:{name:"keywords",content:a.value}}})),i(()=>{r.docNameChange("bomiotconf")}),p(()=>{}),(k,x)=>(f(),u(s,{class:"flex flex-top"},{default:d(()=>[l(c)]),_:1}))}};export{N as default};
