import{b as n,N as o}from"./index-D6xcdmSy.js";const t="right",i=!0,e=!0,s=!0,r="flat",c=3e3,l=n(async()=>{o.registerType("success",{icon:"check_circle",position:t,progress:i,multiLine:e,group:s,color:"positive",textColor:"black",classes:r,timeout:c}),o.registerType("error",{icon:"warning",position:t,progress:i,multiLine:e,group:s,color:"negative",textColor:"white",classes:r,timeout:c}),o.registerType("warning",{icon:"privacy_tip",position:t,progress:i,multiLine:e,group:s,color:"warning",textColor:"black",classes:r,timeout:c}),o.registerType("info",{icon:"privacy_tip",position:t,progress:i,multiLine:e,group:s,color:"info",textColor:"black",classes:r,timeout:c})});export{l as default};
