import{Z as e}from"./index-D6xcdmSy.js";const i=e("rightDrawer",{state:()=>({rightDrawerMenu:!1,rightDrawerOpen:!1}),getters:{rightDrawerMenuGet(r){return r.rightDrawerMenu},rightDrawerOpenGet(r){return r.rightDrawerOpen}},actions:{controlRightDrawer(r){this.rightDrawerOpen=r},toggleRightDrawer(){this.rightDrawerOpen===!1?this.rightDrawerOpen=!0:this.rightDrawerOpen=!1},controlRightDrawerMenu(r){this.rightDrawerMenu=r}},persist:{enable:!0}});export{i as u};
