import{Q as s}from"./QPage-DjgmKzZ_.js";import{u as n}from"./use-meta-Drr87NGw.js";import{u as m,_ as i}from"./MDParser-CdzFjUMI.js";import{r as e,o as c,e as p,ab as u,a3 as l,a7 as d,a6 as f}from"./index-D6xcdmSy.js";import"./rightDrawer-CSGq-HBq.js";import"./axios-B_9szzRp.js";import"./_commonjsHelpers-Cpj98o6Y.js";import"./use-quasar-CxlsMA-r.js";import"./language-BmNUDO97.js";import"./vue-i18n.runtime-BS3IaizX.js";const Q={__name:"TerminalReader",setup(_){const t=e(""),o=e(""),a=e(""),r=m();return n(()=>({title:t.value,meta:{description:{name:"description",content:o.value},keywords:{name:"keywords",content:a.value}}})),c(()=>{r.docNameChange("terminal")}),p(()=>{}),(k,x)=>(l(),u(s,{class:"flex flex-top"},{default:d(()=>[f(i)]),_:1}))}};export{Q as default};
