import{Q as u}from"./QPage-DjgmKzZ_.js";import{e as p,g as m}from"./axios-B_9szzRp.js";import{u as _}from"./use-quasar-CxlsMA-r.js";import{L as f}from"./LineCharts-Dp-gQ-bV.js";import{aL as g,a as i,r as x,o as v,ab as o,a3 as r,a7 as y,as as l,aJ as w,ao as C,a5 as L}from"./index-D6xcdmSy.js";import"./installCanvasRenderer-CfMBnVHW.js";const P={class:"col-12 q-pa-md"},q={__name:"PyPiCharts",setup(k){const a=_(),s=i(()=>a.screen.height*.73),c=i(()=>a.screen.width*.825),n=s.value,t=x({title:"",xAxis_list:[],series_list:[]});function h(){m({url:"core/pypi/charts/"}).then(e=>{t.value=e.pypi_data}).catch(e=>{a.notify({type:"error",message:e}),a.loading.hide()})}v(()=>{d(),h()});function d(){p.on("needLogin",e=>{e&&console.log("needLogin")})}return(e,B)=>(r(),o(u,{class:"flex flex-col q-pa-md"},{default:y(()=>[l("div",{class:"row full-width",style:w({height:`${s.value}px`})},[l("div",P,[t.value.series_list.length?(r(),o(f,{key:0,title:t.value.title,"x-axis-data":t.value.xAxis_list,"series-data":t.value.series_list,"show-legend":!0,"chart-height":L(n),"chart-width":c.value},null,8,["title","x-axis-data","series-data","chart-height","chart-width"])):C("",!0)])],4)]),_:1}))}},b=g(q,[["__scopeId","data-v-4da15453"]]);export{b as default};
